@@ -191,7 +191,7 @@ class RecordLoader:
         if groupName is not None and metadata is None:
             raise Exception("groupBy is not implemented by this RecordLoader, can't group by '%s'" % groupName)
         if groupName is None:
-            return {recordId: recordId for recordId in recordIds}
+            return {recordId: [recordId] for recordId in recordIds}
         
         # group by metadata list
         recordGroups = {}
